==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/caction.h <==
/***************************************************************************
                          caction.h  -  action toolbar item
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Ne nov 3 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@host.sk
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CACTION_H
#define CACTION_H

/*
Current status of cAction class (Nov 6, 2002):
 - requested features implemented
 - new features may still be added
 - code has been tested and it works
*/

#include "csaveablefield.h"

#include <qstring.h>

class KToolBar;

/**
One action in the action toolbar.

  *@author Tomas Mecir
  */

class cAction : public cSaveableField  {
   Q_OBJECT
public: 
  cAction ();
  ~cAction ();
  /** creates a new instance of the class; this is needed because I need to
  create instances of childclasses from within this class, but I don't know
  the exact type of that instance... */
  virtual cSaveableField *newInstance ();

  /** not needed */
  virtual bool match (const QString &what) {return false;};
  /** not needed */
  virtual QString performAction () {return QString::null;};

  /** this one is not needed */
  virtual bool shouldContinue (bool match) {return false;};

  /** load data from a config file*/
  virtual void load (KConfig *config, const QString &group);
  /** save data to a config file*/
  virtual void save (KConfig *config, const QString &group);

  /** returns type of item (light-weight RTTI) */
  virtual int itemType () { return TYPE_ACTION; };

  void setCaption (const QString &s);
  QString getCaption ();
  void setCommand (const QString &s);
  QString getCommand ();
  void setCommand2 (const QString &s);
  QString getCommand2 ();
  void setPushDown (bool how);
  bool isPushDown ();
  void setIconName (const QString &s);
  QString getIconName ();

  /** insert this button to the toolbar */
  void insertToToolbar (int id);
  
protected slots:
  void performAction (int);
  void performPushDownAction (int id);
protected:
  QString caption, command, command2;
  QString iconname;
  bool pushdown;
  KToolBar *toolbar;
  int index;
};

#endif

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/caction.h <==
/***************************************************************************
                          caction.h  -  action toolbar item
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Ne nov 3 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CACTION_H
#define CACTION_H

#include "csaveablefield.h"

#include <qstring.h>

class KToolBar;

/**
One action in the action toolbar.

  *@author Tomas Mecir
  */

class cAction : public cSaveableField  {
   Q_OBJECT
public: 
  cAction ();
  ~cAction ();
  /** creates a new instance of the class; this is needed because I need to
  create instances of childclasses from within this class, but I don't know
  the exact type of that instance... */
  virtual cSaveableField *newInstance ();

  /** not needed */
  virtual bool match (const QString &what) {return false;};
  /** not needed */
  virtual QString performAction () {return QString::null;};

  /** this one is not needed */
  virtual bool shouldContinue (bool match) {return false;};

  /** load data from a config file*/
  virtual void load (KConfig *config, const QString &group);
  /** save data to a config file*/
  virtual void save (KConfig *config, const QString &group);

  /** returns type of item (light-weight RTTI) */
  virtual int itemType () { return TYPE_ACTION; };

  void setCaption (const QString &s);
  QString getCaption ();
  void setCommand (const QString &s);
  QString getCommand ();
  void setCommand2 (const QString &s);
  QString getCommand2 ();
  void setPushDown (bool how);
  bool isPushDown ();
  void setIconName (const QString &s);
  QString getIconName ();

  /** insert this button to the toolbar */
  void insertToToolbar (int id);
  
protected slots:
  void performAction (int);
  void performPushDownAction (int id);
protected:
  QString caption, command, command2;
  QString iconname;
  bool pushdown;
  KToolBar *toolbar;
  int index;
};

#endif
